@@ -13,6 +13,7 @@ from astropy import units
 from astropy.coordinates import SkyCoord
 from astropy.units import Quantity
 from astropy.time import TimeDelta, Time
+import time
 from . import util
 
 from .gui import logger
@@ -221,10 +222,16 @@ class AstromParser(object):
             The file contents extracted into a data structure for programmatic
             access.
         """
-        filehandle = storage.open_vos_or_local(filename, "rb")
-        assert filehandle is not None, "Failed to open file {} ".format(filename)
-        filestr = filehandle.read().decode('utf-8')
-        filehandle.close()
+        while True:
+           try:
+              filehandle = storage.open_vos_or_local(filename, "rb")
+              assert filehandle is not None, "Failed to open file {} ".format(filename)
+              filestr = filehandle.read().decode('utf-8')
+              filehandle.close()
+              break
+           except Exception as ex:
+              print(str(ex))
+              time.sleep(3)
 
         assert filestr is not None, "File contents are None"
 
