@@ -360,7 +360,8 @@ class SSOSParser(object):
             logger.info("Calling predict")
             orbit.predict(obs_date)
             logger.info("Done calling predict")
-            if orbit.dra > 15 * units.arcminute or orbit.ddec > 15.0 * units.arcminute:
+            max_error = float(os.environ.get("MOP_MAX_ERROR", 15))*units.arcminute
+            if orbit.dra > max_error or orbit.ddec > max_error:
                 print("Skipping entry as orbit uncertainty at date {} is large.".format(obs_date))
                 continue
             if expnum in expnums_examined:
@@ -747,7 +748,7 @@ class Query(object):
         if len(lines) < 2 or "An error occured getting the ephemeris" in lines:
             print(lines)
             print(response.url)
-            raise IOError(os.errno.EACCES,
+            raise IOError(-1,
                           "call to SSOIS failed on format error")
 
         if os.access("backdoor.tsv", os.R_OK):
